import { fileURLToPath } from 'url';
import { defineConfig } from 'vitepress';
import footnote from 'markdown-it-footnote';

export default defineConfig({
  title: 'HPG Romein',
  description: ' ',
  lang: 'nl',
  assetsDir: 'immutable',

  themeConfig: {
    sidebar: [
      { text: 'Welkom!', link: '/' },
      { text: '2023',
        collapsed: false,
        items: [
          { text: 'Wat en waarom', link: '/2023/wat/' },
          { text: 'Startreflectie', link: '/2023/startreflectie/' },
          { text: 'Projecten', items: [
            { text: '1. Betonplaat', link: '/2023/betonplaat/' },
            { text: '2. Boek', link: '/2023/boek/' },
            { text: '3a. Top-30 tips', link: '/2023/top30/' },
            { text: '3b. Toekomst', link: '/2023/toekomst/' },
          ] },
          { text: 'Leerdoelen', link: '/2023/leerdoelen/' },
          { text: 'Lessen', link: '/2023/geleerd/' },
          { text: 'Hoe verder?', link: '/2023/hoeverder/' },
          { text: 'Een uitstapje', link: '/2023/bredagelijk/' },
          { text: 'Portfolioverslag', link: '/2023/portfolioverslag/' },
        ],
      },
      { text: '2024',
        collapsed: false,
        items: [
          { text: 'Nieuwe start', link: '/2024/nieuwestart/' },
          { text: 'Inschrijving', link: '/2024/inschrijving/' },
          { text: 'Eerste overeenkomst', link: '/2024/overeenkomst/' },
          { text: 'Kwikstaart', link: '/2024/wagtail/' },
          { text: 'Portfolioverslag', link: '/2024/portfolioverslag/' },
          { text: 'Verzekeringen verkopen', link: '/2024/pluzeker/' },
          { text: 'Malmö', link: '/2024/engageu/' },
          { text: 'Competentiereflectie', link: '/2024/competenties/' },
        ],
      },
      { text: 'Contactpersonen', link: '/contactpersonen' },
    ],

    darkModeSwitchLabel: 'Donker thema',
    lightModeSwitchTitle: 'Donker thema',
    darkModeSwitchTitle: 'Licht thema',
    returnToTopLabel: 'Terug naar boven',

    editLink: {
      pattern: 'https://code.smartyellow.net/romein/hpg/src/branch/main/content/:path',
      text: 'Deze pagina is open source!',
    },

    lastUpdated: {
      text: 'Laatste aanpassing',
      formatOptions: {
        dateStyle: 'long',
        timeStyle: 'short',
      },
    },

    docFooter: {
      prev: 'Vorige',
      next: 'Volgende',
    },

    outline: {
      label: 'Pagina-inhoud',
    },

    search: {
      provider: 'local',
      options: {
        locales: {
          root: {
            translations: {
              button: {
                buttonText: 'Zoeken',
                buttonAriaLabel: 'Zoeken'
              },
              modal: {
                displayDetails: 'Details weergeven',
                resetButtonTitle: 'Zoekbalk leegmaken',
                backButtonTitle: 'Terug',
                noResultsText: 'Geen resultaten voor',
                footer: {
                  selectText: 'selecteren',
                  selectKeyAriaLabel: 'Enter',
                  navigateText: 'naar boven/beneden',
                  navigateUpKeyAriaLabel: 'Pijl omhoog',
                  navigateDownKeyAriaLabel: 'Pijl omlaag',
                  closeText: 'sluiten',
                  closeKeyAriaLabel: 'Escape',
                },
              },
            },
          },
        },
      },
    },

    copyright: `© 2022-${new Date().getFullYear()} Romein van Buren.`,
  },

  head: [
    [ 'script', {
      async: '',
      defer: '',
      src: 'https://static.cloudflareinsights.com/beacon.min.js',
      'data-cf-beacon': '{"token": "e1c160a4aa1641b1b8a387ad6438647b"}',
    } ],
  ],

  markdown: {
    config: md => {
      md.use(footnote);
    },
  },

  vite: {
    resolve: {
      alias: [
        { find: /^.*\/VPDocFooter\.vue$/,
          replacement: fileURLToPath(new URL('./theme/VPDocFooter.vue', import.meta.url)),
        },
      ],
    },
  },
});
